@@ -179,8 +179,17 @@ void MainWindow::SetupThisUi()
        ui->teMain->setProperty("FingerScrollable", true);
 #endif
 
-   ui->teMain->setText(oSettings->value("note","").toString());
-   ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+   QString sFirstRun = oSettings->value("notedate","").toString();
+   if (sFirstRun == "")
+   {
+       ui->teMain->setText("please press the widget for edit mode");
+       ui->lblDate->setText(QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm"));
+
+   } else
+   {
+       ui->teMain->setText(oSettings->value("note","").toString());
+       ui->lblDate->setText(oSettings->value("notedate",QDateTime::currentDateTime().toString("dd.MM.yyyy   HH:mm")).toString());
+   }
 
    delete oSettings;
 
